@@ -1,7 +1,7 @@
 /*
  * frogr-controller.c -- Controller of the whole application
  *
- * Copyright (C) 2009-2020 Mario Sanchez Prada
+ * Copyright (C) 2009-2024 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -662,6 +662,10 @@ _handle_flicksoup_error (FrogrController *self, GError *error, gboolean notify_u
       msg = g_strdup_printf (_("Invalid verification code.\nPlease try again."));
       break;
 
+    case FSP_ERROR_OAUTH_SIGNATURE_INVALID:
+      msg = g_strdup_printf (_("Invalid signature.\nPlease try again."));
+      break;
+
     case FSP_ERROR_SERVICE_UNAVAILABLE:
       msg = g_strdup_printf (_("Error:\nService not available"));
       break;
