@@ -1,7 +1,7 @@
 /*
  * frogr-global-defs.h -- Global definitions and constants
  *
- * Copyright (C) 2009-2012 Mario Sanchez Prada
+ * Copyright (C) 2009-2024 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -40,10 +40,7 @@
 /* Padding to be used in the icon view */
 #define IV_THUMB_PADDING 4
 
-#if DEBUG_ENABLED
+/* Use G_MESSAGES_DEBUG=all to enable these */
 #define DEBUG(...) g_debug (__VA_ARGS__);
-#else
-#define DEBUG(...)
-#endif
 
 #endif
